Welcome to nexb-skeleton's documentation!
=========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   skeleton/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
